#!/bin/bash
#######################################################################
# Author : O.Romain.Jaillet-ramey (orj+bash+dnssec (at) lab3w.fr)
# Date Create : 20221005
# Date Modified : 20221005
# Desc : Checks several DNSSEC zones and restarts the DNS server
#######################################################################

#####-------------------------- CONFIG ----------------------------#####

date_year="$(date +%Y)"
date_month="$(date +%m)"
date_day="$(date +%d)"
date_hour="$(date +%H:%M:%S)"
date="${date_year}-${date_month}-${date_day} ${date_hour}"

#month_more_1m=$((60 * 60 * 24 * 30))

#####-------------------------- CONFIG ----------------------------#####


script_desc() {

        echo "#####---------------------------------------------------------"
        echo "#"
        echo "# DESC : Script to check expiration and sign zone (last day) DNSSEC"
        echo "#"
        echo "# ACTUAL DATE : ${date}"
        #echo "# ACTUAL TIMESTAMP : ${timestamp}"
        #echo "# ACTUAL TIMESTAMP + 1 MONTH : ${timestamp} + ${month_more_1m} = $((${timestamp} + ${month_more_1m}))\n"

        #expire_timestamp="$((${timestamp} + ${month_more_1m}))"
        #expire_date=$(date -d @${expire_timestamp} '+%Y-%m-%d %H:%M:%S')

        #echo "# EXPIRE DATE : ${expire_date}"
        echo "#"
        echo -e "#####---------------------------------------------------------\n"

        echo -e "#####---------------------------------------------------------"

}

# for restart or not restart DNS serveur
status=()

restart_server_dns=0

#------------------------------------------------------------------

script_desc

#------------------------------------------------------------------

#------------------------------------------------------------------
# Zone DNS SEC -> algorithm 8 = RSA SHA 256
#
# dnssec-keygen -a RSASHA256 -b 1024 -n ZONE zw3b.net 
# dnssec-keygen -a RSASHA256 -f KSK -b 2048 -n ZONE zw3b.net
#
#------------------------------------------------------------------

domains_list="zw3b.fr zw3b.tv zw3b.net zw3b.site zw3b.blog lab3w.com lab3w.fr"
for domain in ${domains_list}
do
	/root/dnssec-sign-zones.bash -d ${domain} -f /etc/bind/masters/${domain}.hosts -a 8

	status+=( "$(printf "%d\n" $?)" )
done


#------------------------------------------------------------------
# Zone DNS SEC -> algorithm 13 = ECDSA P256 SHA256
#
# dnssec-keygen -a ECDSAP256SHA256 -n ZONE ipv10.net
# dnssec-keygen -a ECDSAP256SHA256 -f KSK -n ZONE ipv10.net
#
#------------------------------------------------------------------

domains_list="ipv10.net ipv01.net"
for domain in ${domains_list}
do
	/root/dnssec-sign-zones.bash -d ${domain} -f /etc/bind/masters/${domain}.hosts -a 13

	status+=( "$(printf "%d\n" $?)" )
done


#------------------------------------------------------------------
# Verify status return for restart or not restart DNS server
#------------------------------------------------------------------

for code in "${status[@]}"; do

#	echo "Code : ${code}"

	if [ ${code} -eq 150 ]; then
		restart_server_dns=1
	fi
done

#exit

#------------------------------------------------------------------


echo "#####---------------------------------------------------------"

if [ ${restart_server_dns} -eq 1 ]; then

	/etc/init.d/bind9 restart
	echo "+-> Bind server DNS reloading|restarting"

else
	echo "+-> Bind server DNS do not restarting (no zone update)"
fi

echo "#####---------------------------------------------------------"



exit 0

